@@ -77,10 +77,12 @@ class Client:
         self.bot.loop.create_task(self.__loop())
 
     def command_run(self,ctx):
+        print("Command Recieved")
         self.commands += 1
+        print("Check 1")
         if (ctx.author.id not in self.active):
             self.active.append(ctx.author.id)
-
+        print("Check 2")
         command = str(ctx.command)
         command = command.split(" ")
         command = command[0]
@@ -89,7 +91,7 @@ class Client:
             if self.popular[j]["name"] == command:
                 found = True
                 fd=j
-                
+        print("Check 3")        
         if not found:
             self.popular.append({"name":command,"count":"1"})
         else:
